#! /usr/bin/env python
# -*- coding: utf-8 -*-
# vim:fenc=utf-8
#
# Copyright © %YEAR%  <>
#
# Distributed under terms of the %LICENSE% license.

"""

"""

import logging

logger = logging.getLogger(__name__)
import argparse
import os.path as op

import config_default
import imtools
import imtools.sample_data

def sample_data_path():
    return op.expanduser("~/lisa_data/sample_data/")

def get_sample_data():
    keys = imtools.sample_data.data_urls.keys()
    imtools.sample_data.get_sample_data(keys, sample_data_path())


def main():
    logger = logging.getLogger()

    logger.setLevel(logging.DEBUG)
    ch = logging.StreamHandler()
    logger.addHandler(ch)

    # create file handler which logs even debug messages
    # fh = logging.FileHandler('log.txt')
    # fh.setLevel(logging.DEBUG)
    # formatter = logging.Formatter(
    #     '%(asctime)s - %(name)s - %(levelname)s - %(message)s')
    # fh.setFormatter(formatter)
    # logger.addHandler(fh)
    # logger.debug('start')

    # input parser
    parser = argparse.ArgumentParser(
        description=__doc__
    )
    # parser.add_argument(
    #     '-i', '--inputfile',
    #     default=None,
    #     required=True,
    #     help='input file'
    # )
    parser.add_argument(
        '-d', '--debug', action='store_true',
        help='Debug mode')
    args = parser.parse_args()

    if args.debug:
        ch.setLevel(logging.DEBUG)

    get_sample_data()

if __name__ == "__main__":
    main()


#! /usr/bin/env python
# -*- coding: utf-8 -*-
# vim:fenc=utf-8
#
# Copyright © 2015 mjirik <mjirik@mjirik-Latitude-E6520>
#
# Distributed under terms of the MIT license.

"""

"""
import unittest
from nose.plugins.attrib import attr
import sys

from PyQt4.QtGui import QApplication
from PyQt4.QtTest import QTest
from PyQt4.QtCore import Qt
import lisa.histology_analyser_gui as HA_GUI


class HAGUITest(unittest.TestCase):

    def setUp(self):
        '''Create the GUI'''
        self.app = QApplication(sys.argv)

    @attr('interactive')
    def test_click(self):
        pass
        # i5 = self.oseg_w.grid.itemAt(5)
        # dcmdirw = self.oseg_w.uiw['dcmdir']
        # QTest.mouseClick(dcmdirw, Qt.LeftButton)

    @attr('interactive')
    def test_run_and_quit_gui(self):
        """
        Tests event of quit
        """
        self.form = HA_GUI.HistologyAnalyserWindow(
            inputfile='sample_data/biodur_sample',
            crop=[0, 50, 300, 401, 400, 502]
        )

        # TODO remove
        import ipdb; ipdb.set_trace() #  noqa BREAKPOINT
        QTest.mouseClick(self.form.btn_process,
                         Qt.LeftButton)
        # self.assertTrue(self.oseg_w.quit(event=None))


if __name__ == "__main__":
    unittest.main()
